.. include:: ../README.rst
    :end-before: if-doc-stop-here

Table of contents
-----------------
.. toctree::
    :maxdepth: 2

    pages/usage
    autoapi/cloup/index
    pages/contributing
    pages/credits
    pages/changelog
